==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/HTTPIngressRuleValueFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class HTTPIngressRuleValueFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent<A>{
  public HTTPIngressRuleValueFluentImpl() {
  }
  public HTTPIngressRuleValueFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue instance) {
    this.withPaths(instance.getPaths()); 
  }
  private java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> paths =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();
  public A addToPaths(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").add(index >= 0 ? index : _visitables.get("paths").size(), builder);this.paths.add(index >= 0 ? index : paths.size(), builder); return (A)this;
  }
  public A setToPaths(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);
    if (index < 0 || index >= _visitables.get("paths").size()) { _visitables.get("paths").add(builder); } else { _visitables.get("paths").set(index, builder);}
    if (index < 0 || index >= paths.size()) { paths.add(builder); } else { paths.set(index, builder);}
     return (A)this;
  }
  public A addToPaths(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath... items) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").add(builder);this.paths.add(builder);} return (A)this;
  }
  public A addAllToPaths(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> items) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").add(builder);this.paths.add(builder);} return (A)this;
  }
  public A removeFromPaths(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath... items) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").remove(builder);if (this.paths != null) {this.paths.remove(builder);}} return (A)this;
  }
  public A removeAllFromPaths(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> items) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").remove(builder);if (this.paths != null) {this.paths.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPaths(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    if (paths == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> each = paths.iterator();
    final List visitables = _visitables.get("paths");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPaths instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> getPaths() {
    return build(paths);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> buildPaths() {
    return build(paths);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildPath(java.lang.Integer index) {
    return this.paths.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildFirstPath() {
    return this.paths.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildLastPath() {
    return this.paths.get(paths.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildMatchingPath(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder item: paths) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingPath(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder item: paths) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPaths(java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> paths) {
    if (this.paths != null) { _visitables.get("paths").removeAll(this.paths);}
    if (paths != null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>(); for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : paths){this.addToPaths(item);}} else { this.paths = null;} return (A) this;
  }
  public A withPaths(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath... paths) {
    if (this.paths != null) {this.paths.clear();}
    if (paths != null) {for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item :paths){ this.addToPaths(item);}} return (A) this;
  }
  public java.lang.Boolean hasPaths() {
    return paths != null && !paths.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> addNewPath() {
    return new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl.PathsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl.PathsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> setNewPathLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl.PathsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editPath(java.lang.Integer index) {
    if (paths.size() <= index) throw new RuntimeException("Can't edit paths. Index exceeds size.");
    return setNewPathLike(index, buildPath(index));
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editFirstPath() {
    if (paths.size() == 0) throw new RuntimeException("Can't edit first paths. The list is empty.");
    return setNewPathLike(0, buildPath(0));
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editLastPath() {
    int index = paths.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last paths. The list is empty.");
    return setNewPathLike(index, buildPath(index));
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editMatchingPath(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    int index = -1;
    for (int i=0;i<paths.size();i++) { 
    if (predicate.test(paths.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching paths. No match found.");
    return setNewPathLike(index, buildPath(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPIngressRuleValueFluentImpl that = (HTTPIngressRuleValueFluentImpl) o;
    if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(paths,  super.hashCode());
  }
  public class PathsNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PathsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(this, item);
    }
    PathsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) HTTPIngressRuleValueFluentImpl.this.setToPaths(index,builder.build());
    }
    public N endPath() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-networking-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/HTTPIngressRuleValueFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class HTTPIngressRuleValueFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent<A>{
  public HTTPIngressRuleValueFluentImpl() {
  }
  public HTTPIngressRuleValueFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValue instance) {
    this.withPaths(instance.getPaths()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> paths =  new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToPaths(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").add(index >= 0 ? index : _visitables.get("paths").size(), builder);this.paths.add(index >= 0 ? index : paths.size(), builder); return (A)this;
  }
  public A setToPaths(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);
    if (index < 0 || index >= _visitables.get("paths").size()) { _visitables.get("paths").add(builder); } else { _visitables.get("paths").set(index, builder);}
    if (index < 0 || index >= paths.size()) { paths.add(builder); } else { paths.set(index, builder);}
     return (A)this;
  }
  public A addToPaths(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath... items) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").add(builder);this.paths.add(builder);} return (A)this;
  }
  public A addAllToPaths(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> items) {
    if (this.paths == null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>();}
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").add(builder);this.paths.add(builder);} return (A)this;
  }
  public A removeFromPaths(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath... items) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").remove(builder);if (this.paths != null) {this.paths.remove(builder);}} return (A)this;
  }
  public A removeAllFromPaths(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> items) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : items) {io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(item);_visitables.get("paths").remove(builder);if (this.paths != null) {this.paths.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPaths(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    if (paths == null) return (A) this;
    final Iterator<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> each = paths.iterator();
    final List visitables = _visitables.get("paths");
    while (each.hasNext()) {
      io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPaths instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> getPaths() {
    return build(paths);
  }
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> buildPaths() {
    return build(paths);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildPath(java.lang.Integer index) {
    return this.paths.get(index).build();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildFirstPath() {
    return this.paths.get(0).build();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildLastPath() {
    return this.paths.get(paths.size() - 1).build();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath buildMatchingPath(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder item: paths) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingPath(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder item: paths) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPaths(java.util.List<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath> paths) {
    if (this.paths != null) { _visitables.get("paths").removeAll(this.paths);}
    if (paths != null) {this.paths = new java.util.ArrayList<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder>(); for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item : paths){this.addToPaths(item);}} else { this.paths = null;} return (A) this;
  }
  public A withPaths(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath... paths) {
    if (this.paths != null) {this.paths.clear();}
    if (paths != null) {for (io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item :paths){ this.addToPaths(item);}} return (A) this;
  }
  public java.lang.Boolean hasPaths() {
    return paths != null && !paths.isEmpty();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> addNewPath() {
    return new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl.PathsNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> addNewPathLike(io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl.PathsNestedImpl(-1, item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> setNewPathLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluentImpl.PathsNestedImpl(index, item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editPath(java.lang.Integer index) {
    if (paths.size() <= index) throw new RuntimeException("Can't edit paths. Index exceeds size.");
    return setNewPathLike(index, buildPath(index));
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editFirstPath() {
    if (paths.size() == 0) throw new RuntimeException("Can't edit first paths. The list is empty.");
    return setNewPathLike(0, buildPath(0));
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editLastPath() {
    int index = paths.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last paths. The list is empty.");
    return setNewPathLike(index, buildPath(index));
  }
  public io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<A> editMatchingPath(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder> predicate) {
    int index = -1;
    for (int i=0;i<paths.size();i++) { 
    if (predicate.test(paths.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching paths. No match found.");
    return setNewPathLike(index, buildPath(index));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    HTTPIngressRuleValueFluentImpl that = (HTTPIngressRuleValueFluentImpl) o;
    if (paths != null ? !paths.equals(that.paths) :that.paths != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(paths,  additionalProperties,  super.hashCode());
  }
  public class PathsNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressRuleValueFluent.PathsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PathsNestedImpl(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPath item) {
      this.index = index;
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(this, item);
    }
    PathsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1.HTTPIngressPathBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) HTTPIngressRuleValueFluentImpl.this.setToPaths(index,builder.build());
    }
    public N endPath() {
      return and();
    }
    
  }
  
}
